{
  "UnicoreApiUrl": "https://zam2125.zam.kfa-juelich.de:9112/JUWELS/rest/core",
  "Resources": {
    "Queue": "devel",
    "Nodes": 2
  },
  "Environment":{
    "Apptainer": {
      "Path": "/mantik-test.sif",
      "Type": "remote"
    }
  }
}
